
import json


def format_taxpayer_output(input_data):
    if isinstance(input_data, dict):
        # If input is a dictionary (structured data)
        taxpayer_info = input_data.get('taxpayer')
        if taxpayer_info:
            formatted_info = {
                "status": "success",
                "data": {
                    "Taxpayer Name": taxpayer_info.get('legalName', 'N/A'),
                    "Business Name": taxpayer_info.get('businessName', 'N/A'),
                    "Address": taxpayer_info.get('address', 'N/A'),
                    "Contact Email": taxpayer_info.get('contactEmail', 'N/A'),
                    "Contact Number": taxpayer_info.get('contactNumber', 'N/A'),
                    "TIN": taxpayer_info.get('tin', 'N/A'),
                    "Government TIN": taxpayer_info.get('governmentTIN', 'N/A'),
                    "Taxpayer Type": taxpayer_info.get('taxpayerType', 'N/A')
                }
            }
        else:
            formatted_info = {
                "status": "error",
                "message": "The taxpayer does not exist or the state is abnormal!"
            }
    else:
        # If input is a plain text (e.g., "This is wrong")
        formatted_info = {
            "status": "error",
            "message": input_data
        }
    
    return formatted_info


def format_invoice_query_output(input_data):
    if isinstance(input_data, dict):
        # If input is a dictionary (structured data)
        records = input_data.get('records', [])
        if records:
            formatted_records = []
            for record in records:
                formatted_record = {
                    "branchId": record.get('branchId', ''),
                    "branchName": record.get('branchName', ''),
                    "businessName": record.get('businessName', ''),
                    "buyerBusinessName": record.get('buyerBusinessName', ''),
                    "buyerLegalName": record.get('buyerLegalName', ''),
                    "buyerTin": record.get('buyerTin', ''),
                    "currency": record.get('currency', ''),
                    "dataSource": record.get('dataSource', ''),
                    "dateFormat": record.get('dateFormat', 'N/A'),
                    "deviceNo": record.get('deviceNo', ''),
                    "grossAmount": record.get('grossAmount', ''),
                    "id": record.get('id', ''),
                    "invoiceIndustryCode": record.get('invoiceIndustryCode', ''),
                    "invoiceKind": record.get('invoiceKind', ''),
                    "invoiceNo": record.get('invoiceNo', ''),
                    "invoiceType": record.get('invoiceType', ''),
                    "isInvalid": record.get('isInvalid', ''),
                    "isRefund": record.get('isRefund', ''),
                    "issuedDate": record.get('issuedDate', ''),
                    "issuedDateStr": record.get('issuedDateStr', ''),
                    "legalName": record.get('legalName', ''),
                    "nowTime": input_data.get('nowTime', ''),
                    "operator": record.get('operator', ''),
                    "pageIndex": record.get('pageIndex', 0),
                    "pageNo": record.get('pageNo', 0),
                    "pageSize": record.get('pageSize', 0),
                    "referenceNo": record.get('referenceNo', ''),
                    "taxAmount": record.get('taxAmount', ''),
                    "uploadingTime": record.get('uploadingTime', ''),
                    "userName": record.get('userName', '')
                }
                formatted_records.append(formatted_record)
            
            formatted_info = {
                "status": "success",
                "data": {
                    "dateFormat": input_data.get('dateFormat', 'N/A'),
                    "nowTime": input_data.get('nowTime', ''),
                    "page": {
                        "pageCount": input_data.get('page', {}).get('pageCount', 0),
                        "pageNo": input_data.get('page', {}).get('pageNo', 0),
                        "pageSize": input_data.get('page', {}).get('pageSize', 0),
                        "totalSize": input_data.get('page', {}).get('totalSize', 0)
                    },
                    "records": formatted_records,
                    "timeFormat": input_data.get('timeFormat', 'N/A')
                }
            }
        else:
            formatted_info = {
                "status": "error",
                "message": "No invoice records found!"
            }
    else:
        # If input is a plain text (e.g., "This is wrong")
        formatted_info = {
            "status": "error",
            "message": input_data
        }
    
    return formatted_info

def clean_invoice_data_json(input_data):
    cleaned_data = {}
    
    # Extract and clean 'basicInformation' details
    basic_info = input_data.get('basicInformation', {})
    cleaned_basic_info = {
        'antifakeCode': basic_info.get('antifakeCode', ''),
        'currency': basic_info.get('currency', ''),
        'currencyRate': basic_info.get('currencyRate', ''),
        'dataSource': basic_info.get('dataSource', ''),
        'deviceNo': basic_info.get('deviceNo', ''),
        'invoiceId': basic_info.get('invoiceId', ''),
        'invoiceIndustryCode': basic_info.get('invoiceIndustryCode', ''),
        'invoiceKind': basic_info.get('invoiceKind', ''),
        'invoiceNo': basic_info.get('invoiceNo', ''),
        'invoiceType': basic_info.get('invoiceType', ''),
        'isBatch': basic_info.get('isBatch', ''),
        'isInvalid': basic_info.get('isInvalid', ''),
        'isPreview': basic_info.get('isPreview', ''),
        'isRefund': basic_info.get('isRefund', ''),
        'issuedDate': basic_info.get('issuedDate', ''),
        'issuedDatePdf': basic_info.get('issuedDatePdf', ''),
        'operator': basic_info.get('operator', '')
    }
    
    cleaned_data['basicInformation'] = cleaned_basic_info
    
    # Extract and clean 'buyerDetails' details
    buyer_details = input_data.get('buyerDetails', {})
    cleaned_buyer_details = {
        'buyerBusinessName': buyer_details.get('buyerBusinessName', ''),
        'buyerEmail': buyer_details.get('buyerEmail', ''),
        'buyerLegalName': buyer_details.get('buyerLegalName', ''),
        'buyerTin': buyer_details.get('buyerTin', ''),
        'buyerType': buyer_details.get('buyerType', ''),
        'dateFormat': buyer_details.get('dateFormat', ''),
        'nowTime': buyer_details.get('nowTime', ''),
        'pageIndex': buyer_details.get('pageIndex', ''),
        'pageNo': buyer_details.get('pageNo', ''),
        'pageSize': buyer_details.get('pageSize', ''),
        'timeFormat': buyer_details.get('timeFormat', '')
    }
    
    cleaned_data['buyerDetails'] = cleaned_buyer_details
    
    # Extract and clean 'goodsDetails'
    goods_details = input_data.get('goodsDetails', [])
    cleaned_goods_details = []
    for goods_item in goods_details:
        cleaned_goods_item = {
            'deemedFlag': goods_item.get('deemedFlag', ''),
            'discountFlag': goods_item.get('discountFlag', ''),
            'exciseFlag': goods_item.get('exciseFlag', ''),
            'exciseTax': goods_item.get('exciseTax', ''),
            'goodsCategoryId': goods_item.get('goodsCategoryId', ''),
            'goodsCategoryName': goods_item.get('goodsCategoryName', ''),
            'item': goods_item.get('item', ''),
            'itemCode': goods_item.get('itemCode', ''),
            'orderNumber': goods_item.get('orderNumber', ''),
            'qty': goods_item.get('qty', ''),
            'tax': goods_item.get('tax', ''),
            'taxRate': goods_item.get('taxRate', ''),
            'total': goods_item.get('total', ''),
            'unitOfMeasure': goods_item.get('unitOfMeasure', ''),
            'unitPrice': goods_item.get('unitPrice', ''),
            'vatApplicableFlag': goods_item.get('vatApplicableFlag', '')
        }
        cleaned_goods_details.append(cleaned_goods_item)
    
    cleaned_data['goodsDetails'] = cleaned_goods_details
    
    # Extract and clean 'sellerDetails'
    seller_details = input_data.get('sellerDetails', {})
    cleaned_seller_details = {
        'address': seller_details.get('address', ''),
        'branchCode': seller_details.get('branchCode', ''),
        'branchId': seller_details.get('branchId', ''),
        'branchName': seller_details.get('branchName', ''),
        'businessName': seller_details.get('businessName', ''),
        'emailAddress': seller_details.get('emailAddress', ''),
        'legalName': seller_details.get('legalName', ''),
        'referenceNo': seller_details.get('referenceNo', ''),
        'tin': seller_details.get('tin', '')
    }
    
    cleaned_data['sellerDetails'] = cleaned_seller_details
    
    # Extract and clean 'summary'
    summary_info = input_data.get('summary', {})
    cleaned_summary_info = {
        'grossAmount': summary_info.get('grossAmount', ''),
        'itemCount': summary_info.get('itemCount', ''),
        'modeCode': summary_info.get('modeCode', ''),
        'netAmount': summary_info.get('netAmount', ''),
        'qrCode': summary_info.get('qrCode', ''),
        'remarks': summary_info.get('remarks', ''),
        'taxAmount': summary_info.get('taxAmount', '')
    }
    
    cleaned_data['summary'] = cleaned_summary_info
    
    return cleaned_data


def process_creditnote_output(data):
    data_dict = json.loads(data)

    date_format = data_dict.get('dateFormat')
    now_time = data_dict.get('nowTime')
    records = data_dict.get('records', [])

    best_data = []
    for record in records:
        record_data = {
            'applicationTime': record.get('applicationTime'),
            'approveStatus': record.get('approveStatus'),
            'businessName': record.get('businessName'),
            'buyerBusinessName': record.get('buyerBusinessName'),
            'buyerLegalName': record.get('buyerLegalName'),
            'buyerTin': record.get('buyerTin'),
            'currency': record.get('currency'),
            'dataSource': record.get('dataSource'),
            'grossAmount': record.get('grossAmount'),
            'id': record.get('id'),
            'invoiceApplyCategoryCode': record.get('invoiceApplyCategoryCode'),
            'invoiceNo': record.get('invoiceNo'),
            'legalName': record.get('legalName'),
            'nowTime': record.get('nowTime'),
            'oriGrossAmount': record.get('oriGrossAmount'),
            'oriInvoiceNo': record.get('oriInvoiceNo'),
            'pageIndex': record.get('pageIndex'),
            'pageNo': record.get('pageNo'),
            'pageSize': record.get('pageSize'),
            'referenceNo': record.get('referenceNo'),
            'source': record.get('source'),
            'tin': record.get('tin'),
            'totalAmount': record.get('totalAmount'),
            'waitingDate': record.get('waitingDate')
        }
        best_data.append(record_data)

    formatted_output = {
        'dateFormat': date_format,
        'nowTime': now_time,
        'bestData': best_data
    }

    return formatted_output


def currency_output_cleaner(data):
    try:
        if isinstance(data, str):
            # Try to parse input data as JSON
            data = json.loads(data)

        # Ensure `data` is a dictionary after JSON parsing
        if not isinstance(data, dict):
            raise ValueError("Input data is not in the expected dictionary format.")

        formatted_data = {
            'Export Levy': data.get('exportLevy', 'N/A'),
            'Rate': data.get('rate', 'N/A'),
            'Import Duty Levy': data.get('importDutyLevy', 'N/A'),
            'Currency': data.get('currency', 'N/A'),
            'Income Tax': data.get('inComeTax', 'N/A')
        }
    except json.JSONDecodeError as e:
        # Handle JSON parsing errors
        formatted_data = {
            'status': 'error',
            'message': f'Failed to parse input data as JSON: {str(e)}'
        }
    except ValueError as e:
        # Handle unexpected input data format
        formatted_data = {
            'status': 'error',
            'message': str(e)
        }
    
    return formatted_data



import json
from .services import process_response, encode
from .utils import *
from .output_cleaner import *

class EFRISInvoicing:
    def __init__(self, ip, device_number, tin, seller_name):
        self.ip = f'http://{ip}/efristcs/ws/tcsapp/getInformation'
        self.device_number = device_number
        self.tin = tin
        self.seller_name = seller_name

    def efris_post(self, ic, message):
        transformed_data = encode(str(json.dumps(message))).decode()
        data_section = construct_data_section(transformed_data)
        global_info_section = construct_global_info_section(self.device_number, self.tin, ic)
        return_state_info_section = construct_return_state_info_section()

        payload = {
            "data": data_section,
            "globalInfo": global_info_section,
            "returnStateInfo": return_state_info_section
        }
        return process_response(self.ip, payload)
    

    def query_tax_payer_by_tin(self, tin):
        ic = 'T119'
        message = {"tin": tin, "ninBrn": ""}
        
        return format_taxpayer_output(self.efris_post(ic, message))
    
    def query_document(self, fdn, type):
        # type 1 for Invoice and 2 for Receipt
        ic = 'T106'
        message = query_invoice_json(fdn, str(type))
        return format_invoice_query_output(self.efris_post(ic, message))

    def query_invoice_details(self, fdn):
        ic = 'T108'
        message = invoice_details_json(fdn)
        return clean_invoice_data_json(self.efris_post(ic, message))
    
    def system_dictionary(self):
        ic = 'T115'
        message = []
        return self.efris_post(ic, message)


    def credit_notes_query(self):
        ic = 'T111'
        message = credit_note_json()
        return process_creditnote_output(self.efris_post(ic, message))
    
    def credit_note_details(self, id):
        ic = 'T112'
        message = {'id': id}
        return self.efris_post(ic, message)

    def approve_credit_note(self, reference_no, status, id, remarks):
        ic = 'T113'
        # Input validation for kind
        valid_status = {101: 'Approved', 103: 'Rejected'}
        if status not in valid_status:
            raise ValueError(f"The 'status' parameter must be one of the following: {', '.join(f'{k}: {v}' for k, v in valid_status.items())}")

        message = approve_credit_note(reference_no, status, id, remarks)
        return self.efris_post(ic, message)

    def cancel_credit_note(self, inv_fdn, cn_fdn, reason):
        # fdn of the original invoice
        ic = 'T112'
        message = cancel_credit_note(inv_fdn, cn_fdn, reason)
        return self.efris_post(ic, message)
    
    # not implemented
    def z_report(self):
        # fdn of the original invoice
        ic = 'T116' 
        message = {}
        return self.efris_post(ic, message)
    
    def cancel_credit_note_application(self, business_key, refrence_no):
        ic = 'T120' 
        message = {"businessKey": business_key, "referenceNo": refrence_no}
        # response will be null if true
        return self.efris_post(ic, message)
    
    def acquiring_exchange_rate(self, currency):
        ic = 'T121'
        message = {"currency": currency, "issueDate":str(dt_string)}
        return currency_output_cleaner(self.efris_post(ic, message))
    
    def upload_invoice(self, invoice_data, goods_data, tax_data, payment_data):
        ic = 'T109'

        reference_no = invoice_data.get('reference_no')
        operator = invoice_data.get('operator')
        currency = invoice_data.get('currency')
        type = invoice_data.get('type')
        kind = invoice_data.get('kind')
        industry = invoice_data.get('industry')
        tin = invoice_data.get('tin')
        buyer_type = invoice_data.get('buyer_type')

        valid_types = {1: 'Invoice/Receipt', 4: 'Debit Note', 5: 'Credit Memo/rebate'}
        if type not in valid_types:
            raise ValueError(f"The 'type' parameter must be one of the following: {', '.join(f'{k}: {v}' for k, v in valid_types.items())}")
        
        # Input validation for kind
        valid_kinds = {1: 'Invoice', 2: 'Receipt'}
        if kind not in valid_kinds:
            raise ValueError(f"The 'kind' parameter must be one of the following: {', '.join(f'{k}: {v}' for k, v in valid_kinds.items())}")

        # Input validation for buyer_type
        valid_buyer_types = {
            0: 'B2B',
            1: 'B2C',
            2: 'Foreigner',
            3: 'B2G'
        }
        if buyer_type not in valid_buyer_types:
            raise ValueError(f"The 'buyer_type' parameter must be one of the following: {', '.join(f'{k}: {v}' for k, v in valid_buyer_types.items())}")


        # Input validation for kind
        valid_industry = {
            101: 'General Industry',
            102: 'Export',
            104: 'Imported Service',
            105: 'Telecom',
            106: 'Stamp Duty',
            107: 'Hotel Service',
            108: 'Other taxes',
            109: 'Airline Business',
            110: 'EDC'
        }
        if industry not in valid_industry:
            raise ValueError(f"The 'kind' parameter must be one of the following: {', '.join(f'{k}: {v}' for k, v in valid_industry.items())}")

        payload = {
            "sellerDetails":sellers_details(self.tin, self.seller_name, reference_no),
            "basicInformation": basic_info(operator,str(currency), str(type), str(kind)),
            "buyerDetails": buyer_details(str(tin), str(buyer_type)),
            "buyerExtend": buyer_extend(),
            "goodsDetails": goods_data,
            "taxDetails": tax_data,
            "summary": summary_details(),
            "payWay": payment_data,
            "extend":extend_details(),
            "importSericesSeller":import_services_seller(),
            "airlineGoodsDetails": airline_goods_details(),
        }
    
        message = "000f"

        return self.efris_post(ic, message)


#invoicing = EFRISInvoicing('198.74.52.28:9880', 'TCS1613912751699535','1000032574', 'WideSpectrum')
#tax_payer = invoicing.query_invoice_details('323128406449')
#tax_payer = invoicing.acquiring_exchange_rate("USD")


#print('**********************************')
#print(tax_payer)



import requests
import base64
import gzip
import json

def encode(text):
    to_bytes = text.encode('utf-8')
    # 'utf-8' ascii
    return (base64.b64encode(to_bytes))

def decode(text):
    return (base64.b64decode(text))

def decode_content(content):
    decoded_content = base64.b64decode(content.encode('utf-8'))
    decoded_dict = json.loads(decoded_content)
    return decoded_dict

def process_response(ip, data_dump):
    response = requests.post(ip, json=data_dump)
    response.raise_for_status()
    json_data = response.json()
    print('-------------------------')
    print(json_data)

    if json_data['returnStateInfo']['returnMessage'] == 'SUCCESS':
        if json_data['data']['dataDescription']['zipCode'] != '1':
            content = json_data['data']['content']
            decoded_data = decode_content(content)
            return decoded_data
        else:
            content = json_data['data']['content']
            gz = base64.b64decode(content)
            decompressed_data = gzip.decompress(gz).decode('utf-8')
            if isinstance(decompressed_data, str):
                return decompressed_data
            else:
                return json.loads(decompressed_data)
    else:
        # print(f"Error: {json_data['returnStateInfo']['returnMessage']}")
        return json_data['returnStateInfo']['returnMessage']



import pytz
from datetime import datetime

now = datetime.now()
dt_string = datetime.now(pytz.timezone('Africa/Nairobi')).strftime("%Y-%m-%d %H:%M:%S")
date_string = datetime.now(pytz.timezone('Africa/Nairobi')).strftime("%Y-%m-%d")

def construct_data_section(message):
    data_section = {
        "content": message,
        "signature": "",
        "dataDescription": {
            "codeType": "0",
            "encryptCode": "1",
            "zipCode": "0"
        }
    }
    return data_section


def construct_global_info_section(device_number,tin, ic):
    global_info_section = {
        "appId": "AP04",
        "version": "1.1.20191201",
        "dataExchangeId": "9230489223014123",
        "interfaceCode": str(ic),
        "requestCode": "TP",
        "requestTime": str(dt_string),
        "responseCode": "TA",
        "userName": "admin",
        "deviceMAC": "FFFFFFFFFFFF",
        "deviceNo": str(device_number),
        "tin": str(tin),
        "brn": "",
        "taxpayerID": "1",
        "longitude": "116.397128",
        "latitude": "39.916527",
        "extendField": {
            "responseDateFormat": "dd/MM/yyyy",
            "responseTimeFormat": "dd/MM/yyyy HH:mm:ss"
        }
    }
    return global_info_section


def construct_return_state_info_section():
    return_state_info_section = {
        "returnCode": "",
        "returnMessage": ""
    }
    return return_state_info_section


def query_invoice_json(fdn, type):
    request_message = {
    "Request Message": "",  # Descriptive message
    "oriInvoiceNo": "",
    "invoiceNo": str(fdn),
    "deviceNo": "",
    "buyerTin": "",
    "buyerNinBrn": "",
    "buyerLegalName": "",
    "combineKeywords": "",
    "invoiceType": "",
    "invoiceKind": type,
    "isInvalid": "",
    "isRefund": "",
    "startDate": "",
    "endDate": "",
    "pageNo": "1",
    "pageSize": "98",
    "referenceNo": "",
    "branchName": "",
    "queryType": "",
    "dataSource": "",
    "sellerTinOrNin": "",
    "sellerLegalOrBusinessName": ""
    }
    return request_message

def invoice_details_json(fdn):
    request_message = {
    "invoiceNo": str(fdn),
    }
    return request_message


# invoice upload jsons
def sellers_details(tin, name, reference_no):
    data = {
        "tin": tin,
        "ninBrn": "",
        "legalName": name,
        "businessName": "",
        "address": "",
        "mobilePhone": "",
        "linePhone": "",
        "emailAddress": "",
        "placeOfBusiness": "",
        "referenceNo": reference_no,
        "branchId": "",
        "branchName": "Main",
        "isCheckReferenceNo": ""
    }
    return data

def basic_info(operator, currency, type, kind):
    data ={
        "invoiceNo": "",
        "antifakeCode": "",
        "deviceNo": "",
        "issuedDate": str(dt_string),
        "operator": operator,
        "currency": currency,
        "oriInvoiceId": "",
        "invoiceType": type,
        "invoiceKind": kind,
        "dataSource": "106",
        "invoiceIndustryCode": "",
        "isBatch": ""
    }
    return data


def buyer_details(tin, buyer_type):
    data = {
        "buyerTin": tin,
        "buyerNinBrn": "",
        "buyerPassportNum": "",
        "buyerLegalName": "",
        "buyerBusinessName": "",
        "buyerAddress": "",
        "buyerEmail": "",
        "buyerMobilePhone": "",
        "buyerLinePhone": "",
        "buyerPlaceOfBusi": "",
        "buyerType": buyer_type,
        "buyerCitizenship": "",
        "buyerSector": "",
        "buyerReferenceNo": "",
        "nonResidentFlag": ""
    }
    return data

def buyer_extend():
    data = {
        "propertyType": "",
        "district": "",
        "municipalityCounty": "",
        "divisionSubcounty": "",
        "town": "",
        "cellVillage": "",
        "effectiveRegistrationDate": "",
        "meterStatus": ""
    }
    return data

def goods_details():
    data = {
        "item": "",
        "itemCode": "",
        "qty": "",
        "unitOfMeasure": "",
        "unitPrice": "",
        "total": "",
        "taxRate": "",
        "tax": "",
        "discountTotal": "",
        "discountTaxRate": "",
        "orderNumber": "",
        "discountFlag": "",
        "deemedFlag": "",
        "exciseFlag": "",
        "categoryId": "",
        "categoryName": "",
        "goodsCategoryId": "",
        "goodsCategoryName": "",
        "exciseRate": "",
        "exciseRule": "",
        "exciseTax": "",
        "pack": "",
        "stick": "",
        "exciseUnit": "",
        "exciseCurrency": "",
        "exciseRateName": "",
        "vatApplicableFlag": "",
        "deemedExemptCode": "",
        "vatProjectId": "",
        "vatProjectName": ""
    }
    return data

def tax_details():
    data = {
        "taxCategoryCode": "",
        "netAmount": "",
        "taxRate": "",
        "taxAmount": "",
        "grossAmount": "",
        "exciseUnit": "",
        "exciseCurrency": "",
        "taxRateName": ""
    }
    return data

def summary_details():  
    data = {
        "netAmount": "",
        "taxAmount": "",
        "grossAmount": "",
        "itemCount": "",
        "modeCode": "",
        "remarks": "",
        "qrCode": ""
    }
    return data

def payment_details():  
    data = {
        "paymentMode": "",
        "paymentAmount": "",
        "orderNumber": ""
    }
    return data

def extend_details():  
    data = {
        "reason": "",
        "reasonCode": ""
    }
    return data

def import_services_seller():  
    data = {
        "importBusinessName": "",
        "importEmailAddress": "",
        "importContactNumber": "",
        "importAddress": "",
        "importInvoiceDate": "",
        "importAttachmentName": "",
        "importAttachmentContent": ""
    }
    return data

def airline_goods_details():  
    data = {
        "airlineGoodsDetails": ""
    }
    return data


def credit_note_json():
    data = {
    "referenceNo": "",
    "oriInvoiceNo": "",
    "invoiceNo": "",
    "combineKeywords": "",
    "approveStatus": "",
    "queryType": "1",
    "invoiceApplyCategoryCode": "",
    "startDate": "",
    "endDate": "",
    "pageNo": "1",
    "pageSize": "99",
    "creditNoteType": "",
    "branchName": "",
    "sellerTinOrNin": "",
    "sellerLegalOrBusinessName": ""
    }
    return data


def approve_credit_note(ref_no, status, id, remarks):
    data = {
    "referenceNo": ref_no,
    "approveStatus": status,
    "taskId": id,
    "remark": remarks
    }
    return data

def cancel_credit_note(fdn, cn_fdn, reason):
    data = {
    "oriInvoiceId": fdn,
    "invoiceNo": cn_fdn,
    "reason": reason,
    "reasonCode": "103",
    "invoiceApplyCategoryCode": "104",
    "attachmentList": [{
        "fileName": "",
        "fileType": "",
        "fileContent": ""
    }]
}

    return data


from setuptools import setup, find_packages

setup(
    name='efriser',
    version='0.1.6',
    author='Douglas Ssekuwanda',
    author_email='cytixdoug@gmail.com',
    description='This is a python package to aid in fiscalisation of invoices with the Uganda Revenue Authority (URA) using the EFRIS API.',
    packages=find_packages(),
    install_requires=[
        'requests>=2.24.0',
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)